@@ -26,15 +26,28 @@
 
 
 AkonotesIndexer::AkonotesIndexer(const QString& path)
-    : AbstractIndexer(), m_termGen( 0 )
+    : AbstractIndexer(), m_db(0), m_termGen( 0 )
 {
-    m_db = new Xapian::WritableDatabase(path.toUtf8().constData(), Xapian::DB_CREATE_OR_OPEN);
+    try {
+        m_db = new Xapian::WritableDatabase(path.toUtf8().constData(), Xapian::DB_CREATE_OR_OPEN);
+    }
+    catch (const Xapian::DatabaseCorruptError& err) {
+        qWarning() << "Database Corrupted - What did you do?";
+        qWarning() << err.get_error_string();
+        m_db = 0;
+    }
+    catch (const Xapian::Error &e) {
+        qWarning() << QString::fromStdString(e.get_type()) << QString::fromStdString(e.get_description());
+        m_db = 0;
+    }
 }
 
 AkonotesIndexer::~AkonotesIndexer()
 {
-    m_db->commit();
-    delete m_db;
+    if (m_db) {
+        m_db->commit();
+        delete m_db;
+    }
 }
 
 QStringList AkonotesIndexer::mimeTypes() const
@@ -44,6 +57,8 @@ QStringList AkonotesIndexer::mimeTypes() const
 
 void AkonotesIndexer::index(const Akonadi::Item &item)
 {
+    if (!m_db)
+        return;
     KMime::Message::Ptr msg;
     try {
         msg = item.payload<KMime::Message::Ptr>();
@@ -125,11 +140,14 @@ void AkonotesIndexer::processPart(KMime::Content* content, KMime::Content* mainC
 
 void AkonotesIndexer::commit()
 {
-    m_db->commit();
+    if (m_db)
+        m_db->commit();
 }
 
 void AkonotesIndexer::remove(const Akonadi::Item &item)
 {
+    if (!m_db)
+        return;
     try {
         m_db->delete_document(item.id());
     }
@@ -140,6 +158,8 @@ void AkonotesIndexer::remove(const Akonadi::Item &item)
 
 void AkonotesIndexer::remove(const Akonadi::Collection& collection)
 {
+    if (!m_db)
+        return;
     try {
         Xapian::Query query('C'+ QString::number(collection.id()).toStdString());
         Xapian::Enquire enquire(*m_db);
@@ -156,3 +176,26 @@ void AkonotesIndexer::remove(const Akonadi::Collection& collection)
         return;
     }
 }
+
+void AkonotesIndexer::move(const Akonadi::Item::Id& itemId,
+                        const Akonadi::Entity::Id& from,
+                        const Akonadi::Entity::Id& to)
+{
+    if (!m_db)
+        return;
+    Xapian::Document doc;
+    try {
+        doc = m_db->get_document(itemId);
+    }
+    catch (const Xapian::DocNotFoundError&) {
+        return;
+    }
+
+    const QByteArray ft = 'C' + QByteArray::number(from);
+    const QByteArray tt = 'C' + QByteArray::number(to);
+
+    doc.remove_term(ft.data());
+    doc.add_boolean_term(tt.data());
+    m_db->replace_document(doc.get_docid(), doc);
+}
+
